import React from 'react';
import { Hook } from 'tapable';
import Plugin from '../plugins';
interface FilterMeta {
    filter: string;
}
interface FetchMeta {
    url: string;
    method?: string;
    data?: {
        [x: string]: any;
    }[];
}
export interface ActionMeta {
    label: string;
    modal?: string;
    link?: string;
    url?: string;
}
interface LayoutMeta {
    direction: string;
    width?: number;
}
export declare type Meta = FilterMeta | FetchMeta | ActionMeta | LayoutMeta;
export interface PageSectionItem {
    key: string;
    label: string;
    id?: boolean;
    type?: string;
    meta?: FetchMeta;
}
export interface PageSection {
    type: string;
    key: string;
    items?: (PageSectionItem | PageSection)[];
    meta?: Meta;
}
export interface MenuItem {
    key: string;
    label: string;
    pageJSON?: PageSection[];
    index?: boolean;
    params?: string[];
}
export interface MenuGroup {
    label: string;
    subs: MenuItem[];
}
export declare function isMenuGroup(item: MenuItem | MenuGroup): item is MenuGroup;
export interface ConfigType {
    appKey: string;
    appTitle: string;
    menus: (MenuGroup | MenuItem)[];
    pageAPI?: string;
    loginUrl?: string;
}
export interface AppHooks {
    afterMenusFetched: Hook;
    afterPageLoaded: Hook;
    afterPageUnloaded: Hook;
    afterComponentLoaded: Hook;
    afterComponentUnloaded: Hook;
    beforeFormSelectFetched: Hook;
    afterFormSelectFetched: Hook;
    beforeTableDataSourceFetched: Hook;
    afterTableDataSourceFetched: Hook;
    beforeTableColumnFinalization: Hook;
    beforeButtonClick: Hook;
    beforeFormSubmit: Hook;
}
interface AppType {
    config: ConfigType;
    hooks: AppHooks;
}
export declare const App: React.Context<AppType>;
interface IProps {
    config: ConfigType;
    plugins: Plugin[];
    debugHooks?: string[];
    children: React.ReactNode;
}
export declare function AppProvider(props: IProps): JSX.Element;
export {};
